Class: Google::Api::BatchingDescriptorProto
- Inherits:
-
Object
- Object
- Google::Api::BatchingDescriptorProto
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/api/client.rb
Overview
BatchingDescriptorProto specifies the fields of the request message to be
used for batching, and, optionally, the fields of the response message to be
used for demultiplexing.
Instance Attribute Summary collapse
-
#batched_field ⇒ ::String
The repeated field in the request message to be aggregated by batching.
-
#discriminator_fields ⇒ ::Array<::String>
A list of the fields in the request message.
-
#subresponse_field ⇒ ::String
Optional.
Instance Attribute Details
#batched_field ⇒ ::String
Returns The repeated field in the request message to be aggregated by batching.
531 532 533 534 |
# File 'proto_docs/google/api/client.rb', line 531 class BatchingDescriptorProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#discriminator_fields ⇒ ::Array<::String>
Returns A list of the fields in the request message. Two requests will be batched
together only if the values of every field specified in
request_discriminator_fields is equal between the two requests.
531 532 533 534 |
# File 'proto_docs/google/api/client.rb', line 531 class BatchingDescriptorProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subresponse_field ⇒ ::String
Returns Optional. When present, indicates the field in the response message to be used to demultiplex the response into multiple response messages, in correspondence with the multiple request messages originally batched together.
531 532 533 534 |
# File 'proto_docs/google/api/client.rb', line 531 class BatchingDescriptorProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |