Class: Google::Shopping::Merchant::Inventories::V1::DeleteRegionalInventoryRequest
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Inventories::V1::DeleteRegionalInventoryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb
Overview
Request message for the DeleteRegionalInventory method.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the RegionalInventory resource to delete.
Format:
accounts/{account}/products/{product}/regionalInventories/{region}
The {product} segment is a unique identifier for the product.
This identifier must be unique within a merchant account and generally
follows the structure: content_language~feed_label~offer_id. Example:
en~US~sku123 For legacy local products, the structure is:
local~content_language~feed_label~offer_id. Example: local~en~US~sku123
The format of the {product} segment in the URL is automatically detected
by the server, supporting two options:
Encoded Format: The
{product}segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in thecontent_language~feed_label~offer_idstructure. This encoding MUST be used if any part of the product identifier (likeoffer_id) contains characters such as/,%, or~.- Example: To represent the product ID
en~US~sku/123forregion"region123", the{product}segment must be the unpadded base64url encoding of this string, which isZW5-VVN-c2t1LzEyMw. The full resource name for the regional inventory would beaccounts/123/products/ZW5-VVN-c2t1LzEyMw/regionalInventories/region123.
- Example: To represent the product ID
Plain Format: The
{product}segment is the tilde-separated stringcontent_language~feed_label~offer_id. This format is suitable only whencontent_language,feed_label, andoffer_iddo not contain URL-problematic characters like/,%, or~.
We recommend using the Encoded Format for all product IDs to ensure
correct parsing, especially those containing special characters. The
presence of tilde (~) characters in the {product} segment is used to
differentiate between the two formats.
254 255 256 257 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb', line 254 class DeleteRegionalInventoryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |