Class: Google::Shopping::Merchant::Inventories::V1::InsertRegionalInventoryRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb

Overview

Request message for the InsertRegionalInventory method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The account and product where this inventory will be inserted. Format: accounts/{account}/products/{product}

The {product} segment is a unique identifier for the product. This identifier must be unique within a merchant account and generally follows the structure: content_language~feed_label~offer_id. Example: en~US~sku123 For legacy local products, the structure is: local~content_language~feed_label~offer_id. Example: local~en~US~sku123

The format of the {product} segment in the URL is automatically detected by the server, supporting two options:

  1. Encoded Format: The {product} segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in the content_language~feed_label~offer_id structure. This encoding MUST be used if any part of the product identifier (like offer_id) contains characters such as /, %, or ~.

    • Example: To represent the product ID en~US~sku/123, the {product} segment must be the unpadded base64url encoding of this string, which is ZW5-VVN-c2t1LzEyMw. The full resource name for the product would be accounts/123/products/ZW5-VVN-c2t1LzEyMw.
  2. Plain Format: The {product} segment is the tilde-separated string content_language~feed_label~offer_id. This format is suitable only when content_language, feed_label, and offer_id do not contain URL-problematic characters like /, %, or ~.

We recommend using the Encoded Format for all product IDs to ensure correct parsing, especially those containing special characters. The presence of tilde (~) characters in the {product} segment is used to differentiate between the two formats.

Returns:

  • (::String)

    Required. The account and product where this inventory will be inserted. Format: accounts/{account}/products/{product}

    The {product} segment is a unique identifier for the product. This identifier must be unique within a merchant account and generally follows the structure: content_language~feed_label~offer_id. Example: en~US~sku123 For legacy local products, the structure is: local~content_language~feed_label~offer_id. Example: local~en~US~sku123

    The format of the {product} segment in the URL is automatically detected by the server, supporting two options:

    1. Encoded Format: The {product} segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in the content_language~feed_label~offer_id structure. This encoding MUST be used if any part of the product identifier (like offer_id) contains characters such as /, %, or ~.

      • Example: To represent the product ID en~US~sku/123, the {product} segment must be the unpadded base64url encoding of this string, which is ZW5-VVN-c2t1LzEyMw. The full resource name for the product would be accounts/123/products/ZW5-VVN-c2t1LzEyMw.
    2. Plain Format: The {product} segment is the tilde-separated string content_language~feed_label~offer_id. This format is suitable only when content_language, feed_label, and offer_id do not contain URL-problematic characters like /, %, or ~.

    We recommend using the Encoded Format for all product IDs to ensure correct parsing, especially those containing special characters. The presence of tilde (~) characters in the {product} segment is used to differentiate between the two formats.



211
212
213
214
# File 'proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb', line 211

class InsertRegionalInventoryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#regional_inventory::Google::Shopping::Merchant::Inventories::V1::RegionalInventory

Returns Required. Regional inventory information to add to the product. If the product already has a RegionalInventory resource for the same region, full replacement of the RegionalInventory resource is performed.

Returns:



211
212
213
214
# File 'proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb', line 211

class InsertRegionalInventoryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end