Class: Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb

Overview

Local inventory attributes.

Defined Under Namespace

Modules: Availability, PickupMethod, PickupSla

Instance Attribute Summary collapse

Instance Attribute Details

#availability::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::Availability

Returns Availability of the product at this store.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#custom_attributes::Array<::Google::Shopping::Type::CustomAttribute>

Returns Optional. A list of custom (merchant-provided) attributes. It can also be used for submitting any attribute of the data specification in its generic form (for example, { "name": "size type", "value": "regular" }). This is useful for submitting attributes not explicitly exposed by the API. Maximum allowed number of characters for each custom attribute is 10240 (represents sum of characters for name and value). Maximum 2500 custom attributes can be set, with total size of 102.4kB. Underscores in custom attribute names are replaced by spaces upon insertion.

Returns:

  • (::Array<::Google::Shopping::Type::CustomAttribute>)

    Optional. A list of custom (merchant-provided) attributes. It can also be used for submitting any attribute of the data specification in its generic form (for example, { "name": "size type", "value": "regular" }). This is useful for submitting attributes not explicitly exposed by the API. Maximum allowed number of characters for each custom attribute is 10240 (represents sum of characters for name and value). Maximum 2500 custom attributes can be set, with total size of 102.4kB. Underscores in custom attribute names are replaced by spaces upon insertion.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#instore_product_location::String

Returns Optional. Location of the product inside the store. Maximum length is 20 bytes.

Returns:

  • (::String)

    Optional. Location of the product inside the store. Maximum length is 20 bytes.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#local_shipping_label::String

Returns Optional. Specifies a label associated with the shipping for the LocalInventory resource. Can be used to group local shipping services to this particular inventory item. For accepted field format, see the Local delivery.

Returns:

  • (::String)

    Optional. Specifies a label associated with the shipping for the LocalInventory resource. Can be used to group local shipping services to this particular inventory item. For accepted field format, see the Local delivery



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#loyalty_programs::Array<::Google::Shopping::Merchant::Inventories::V1::InventoryLoyaltyProgram>

Returns Optional. An optional list of loyalty programs containing applicable loyalty member prices for this product at this store.

This field is used to show store-specific member prices on Local Inventory Ads (LIA).

To use this, the loyalty program must be configured in Google Merchant Center. The benefits provided must match the merchant's website and be clear to members. This is only applicable for merchants in supported countries.

See Loyalty program for details on supported countries and loyalty program configuration. For local inventory specific details, see the Local inventory data specification.

Returns:

  • (::Array<::Google::Shopping::Merchant::Inventories::V1::InventoryLoyaltyProgram>)

    Optional. An optional list of loyalty programs containing applicable loyalty member prices for this product at this store.

    This field is used to show store-specific member prices on Local Inventory Ads (LIA).

    To use this, the loyalty program must be configured in Google Merchant Center. The benefits provided must match the merchant's website and be clear to members. This is only applicable for merchants in supported countries.

    See Loyalty program for details on supported countries and loyalty program configuration. For local inventory specific details, see the Local inventory data specification.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#pickup_method::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::PickupMethod

Returns Optional. Supported pickup method for this product. Unless the value is "not supported", this field must be submitted together with pickupSla.

Returns:



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#pickup_sla::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::PickupSla

Returns Optional. Relative time period from the order date for an order for this product, from this store, to be ready for pickup. Must be submitted with pickupMethod. See more details here.

Returns:



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#price::Google::Shopping::Type::Price

Returns Optional. Price of the product at this store.

Returns:



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#quantity::Integer

Returns Optional. Quantity of the product available at this store. Must be greater than or equal to zero.

Returns:

  • (::Integer)

    Optional. Quantity of the product available at this store. Must be greater than or equal to zero.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#sale_price::Google::Shopping::Type::Price

Returns Optional. Sale price of the product at this store. Mandatory if [salePriceEffectiveDate][LocalInventory.sale_price_effective_date] is defined.

Returns:

  • (::Google::Shopping::Type::Price)

    Optional. Sale price of the product at this store. Mandatory if [salePriceEffectiveDate][LocalInventory.sale_price_effective_date] is defined.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end

#sale_price_effective_date::Google::Type::Interval

Returns Optional. The TimePeriod of the sale at this store.

Returns:



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 95

class LocalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/3061342) of the
  # product at this store.
  module Availability
    # Indicates that the availability is unspecified.
    LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    LIMITED_AVAILABILITY = 2

    # Indicates that the product is on display to order.
    ON_DISPLAY_TO_ORDER = 3

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 4
  end

  # Supported [pickup
  # method](https://support.google.com/merchants/answer/3061342) for this
  # product. Unless the value is `"not supported"`, this field must be
  # submitted together with `pickupSla`.
  module PickupMethod
    # Indicates that the pickup method is unspecified.
    PICKUP_METHOD_UNSPECIFIED = 0

    # Indicates that the pickup method is Buy.
    BUY = 1

    # Indicates that the pickup method is Reserve.
    RESERVE = 2

    # Indicates that the pickup method is Ship to store.
    SHIP_TO_STORE = 3

    # Indicates that the pickup method is not supported.
    NOT_SUPPORTED = 4
  end

  # Relative time period from the order date for an order for this product,
  # from this store, to be ready for pickup. Must be submitted with
  # `pickupMethod`. See more details
  # [here](https://support.google.com/merchants/answer/3061342).
  module PickupSla
    # Indicates that the pickup SLA is unspecified.
    PICKUP_SLA_UNSPECIFIED = 0

    # Indicates that the pickup SLA is same day.
    SAME_DAY = 1

    # Indicates that the pickup SLA is next day.
    NEXT_DAY = 2

    # Indicates that the pickup SLA is two days.
    TWO_DAY = 3

    # Indicates that the pickup SLA is three days.
    THREE_DAY = 4

    # Indicates that the pickup SLA is four days.
    FOUR_DAY = 5

    # Indicates that the pickup SLA is five days.
    FIVE_DAY = 6

    # Indicates that the pickup SLA is six days.
    SIX_DAY = 7

    # Indicates that the pickup SLA is seven days.
    SEVEN_DAY = 8

    # Indicates that the pickup SLA is multi-week.
    MULTI_WEEK = 9
  end
end