Class: Google::Shopping::Merchant::Inventories::V1::LocalInventoryService::Client
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Inventories::V1::LocalInventoryService::Client
- Includes:
- Paths
- Defined in:
- lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb
Overview
Client for the LocalInventoryService service.
Service to manage local inventory for products
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the LocalInventoryService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the LocalInventoryService Client instance.
-
#delete_local_inventory(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes the specified
LocalInventoryfrom the given product in your merchant account. -
#initialize {|config| ... } ⇒ Client
constructor
Create a new LocalInventoryService client object.
-
#insert_local_inventory(request, options = nil) {|response, operation| ... } ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventory
Inserts a
LocalInventoryresource to a product in your merchant account. -
#list_local_inventories(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Shopping::Merchant::Inventories::V1::LocalInventory>
Lists the
LocalInventoryresources for the given product in your merchant account. -
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#local_inventory_path, #product_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new LocalInventoryService client object.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb', line 130 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/shopping/merchant/inventories/v1/localinventory_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @local_inventory_service_stub = ::Gapic::ServiceStub.new( ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @local_inventory_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the LocalInventoryService Client class.
See Configuration for a description of the configuration fields.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Shopping", "Merchant", "Inventories", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the LocalInventoryService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
100 101 102 103 |
# File 'lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb', line 100 def configure yield @config if block_given? @config end |
#delete_local_inventory(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_local_inventory(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes the specified LocalInventory from the given product in your
merchant account. It might take a up to an hour for the
LocalInventory to be deleted from the specific product.
Once you have received a successful delete response, wait for that
period before attempting a delete again.
543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb', line 543 def delete_local_inventory request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Shopping::Merchant::Inventories::V1::DeleteLocalInventoryRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_local_inventory..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Shopping::Merchant::Inventories::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_local_inventory.timeout, metadata: , retry_policy: @config.rpcs.delete_local_inventory.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @local_inventory_service_stub.call_rpc :delete_local_inventory, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#insert_local_inventory(request, options = nil) ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventory #insert_local_inventory(parent: nil, local_inventory: nil) ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventory
Inserts a LocalInventory resource to a product in your merchant
account.
Replaces the full LocalInventory resource if an entry with the same
`storeCode`
already exists for the product.
It might take up to 30 minutes for the new or updated LocalInventory
resource to appear in products.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb', line 421 def insert_local_inventory request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Shopping::Merchant::Inventories::V1::InsertLocalInventoryRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.insert_local_inventory..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Shopping::Merchant::Inventories::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.insert_local_inventory.timeout, metadata: , retry_policy: @config.rpcs.insert_local_inventory.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @local_inventory_service_stub.call_rpc :insert_local_inventory, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_local_inventories(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Shopping::Merchant::Inventories::V1::LocalInventory> #list_local_inventories(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Shopping::Merchant::Inventories::V1::LocalInventory>
Lists the LocalInventory resources for the given product in your merchant
account. The response might contain fewer items than specified by
pageSize. If pageToken was returned in previous request, it can be used
to obtain additional results.
LocalInventory resources are listed per product for a given account.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb', line 291 def list_local_inventories request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Shopping::Merchant::Inventories::V1::ListLocalInventoriesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_local_inventories..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Shopping::Merchant::Inventories::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_local_inventories.timeout, metadata: , retry_policy: @config.rpcs.list_local_inventories.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @local_inventory_service_stub.call_rpc :list_local_inventories, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @local_inventory_service_stub, :list_local_inventories, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
186 187 188 |
# File 'lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb', line 186 def logger @local_inventory_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
110 111 112 |
# File 'lib/google/shopping/merchant/inventories/v1/local_inventory_service/client.rb', line 110 def universe_domain @local_inventory_service_stub.universe_domain end |