Class: Google::Shopping::Merchant::Inventories::V1::RegionalInventory

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb

Overview

Regional inventory information for the product. Represents specific information like price and availability for a given product in a specific region. For a list of all accepted attribute values, see the regional product inventory data specification.

Instance Attribute Summary collapse

Instance Attribute Details

#account::Integer (readonly)

Returns Output only. The account that owns the product. This field will be ignored if set by the client.

Returns:

  • (::Integer)

    Output only. The account that owns the product. This field will be ignored if set by the client.



94
95
96
97
# File 'proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb', line 94

class RegionalInventory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#base64_encoded_name::String (readonly)

Returns Output only. The unpadded base64url encoded name of the RegionalInventory resource. Format: accounts/{account}/products/{product}/regionalInventories/{region} where the {product} segment is the unpadded base64url encoded value of the identifier of the form content_language~feed_label~offer_id. Example: accounts/123/products/ZW5-VVN-c2t1LzEyMw/regionalInventories/region123 for the decoded product ID en~US~sku/123 and region "region123". Can be used directly as input to the API methods that require the product identifier within the regional inventory name to be encoded if it contains special characters, for example GetRegionalInventory.

Returns:

  • (::String)

    Output only. The unpadded base64url encoded name of the RegionalInventory resource. Format: accounts/{account}/products/{product}/regionalInventories/{region} where the {product} segment is the unpadded base64url encoded value of the identifier of the form content_language~feed_label~offer_id. Example: accounts/123/products/ZW5-VVN-c2t1LzEyMw/regionalInventories/region123 for the decoded product ID en~US~sku/123 and region "region123". Can be used directly as input to the API methods that require the product identifier within the regional inventory name to be encoded if it contains special characters, for example GetRegionalInventory.



94
95
96
97
# File 'proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb', line 94

class RegionalInventory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String (readonly)

Returns Output only. The name of the RegionalInventory resource. Format: accounts/{account}/products/{product}/regionalInventories/{region}

The {product} segment is a unique identifier for the product. This identifier must be unique within a merchant account and generally follows the structure: content_language~feed_label~offer_id. Example: en~US~sku123 For legacy local products, the structure is: local~content_language~feed_label~offer_id. Example: local~en~US~sku123

The format of the {product} segment in the URL is automatically detected by the server, supporting two options:

  1. Encoded Format: The {product} segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in the content_language~feed_label~offer_id structure. This encoding MUST be used if any part of the product identifier (like offer_id) contains characters such as /, %, or ~.

    • Example: To represent the product ID en~US~sku/123 for region "region123", the {product} segment must be the unpadded base64url encoding of this string, which is ZW5-VVN-c2t1LzEyMw. The full resource name for the regional inventory would be accounts/123/products/ZW5-VVN-c2t1LzEyMw/regionalInventories/region123.
  2. Plain Format: The {product} segment is the tilde-separated string content_language~feed_label~offer_id. This format is suitable only when content_language, feed_label, and offer_id do not contain URL-problematic characters like /, %, or ~.

We recommend using the Encoded Format for all product IDs to ensure correct parsing, especially those containing special characters. The presence of tilde (~) characters in the {product} segment is used to differentiate between the two formats.

Returns:

  • (::String)

    Output only. The name of the RegionalInventory resource. Format: accounts/{account}/products/{product}/regionalInventories/{region}

    The {product} segment is a unique identifier for the product. This identifier must be unique within a merchant account and generally follows the structure: content_language~feed_label~offer_id. Example: en~US~sku123 For legacy local products, the structure is: local~content_language~feed_label~offer_id. Example: local~en~US~sku123

    The format of the {product} segment in the URL is automatically detected by the server, supporting two options:

    1. Encoded Format: The {product} segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in the content_language~feed_label~offer_id structure. This encoding MUST be used if any part of the product identifier (like offer_id) contains characters such as /, %, or ~.

      • Example: To represent the product ID en~US~sku/123 for region "region123", the {product} segment must be the unpadded base64url encoding of this string, which is ZW5-VVN-c2t1LzEyMw. The full resource name for the regional inventory would be accounts/123/products/ZW5-VVN-c2t1LzEyMw/regionalInventories/region123.
    2. Plain Format: The {product} segment is the tilde-separated string content_language~feed_label~offer_id. This format is suitable only when content_language, feed_label, and offer_id do not contain URL-problematic characters like /, %, or ~.

    We recommend using the Encoded Format for all product IDs to ensure correct parsing, especially those containing special characters. The presence of tilde (~) characters in the {product} segment is used to differentiate between the two formats.



94
95
96
97
# File 'proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb', line 94

class RegionalInventory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region::String

Returns Required. Immutable. ID of the region for this RegionalInventory resource. See the Regional availability and pricing for more details.

Returns:



94
95
96
97
# File 'proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb', line 94

class RegionalInventory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#regional_inventory_attributes::Google::Shopping::Merchant::Inventories::V1::RegionalInventoryAttributes

Returns Optional. A list of regional inventory attributes.

Returns:



94
95
96
97
# File 'proto_docs/google/shopping/merchant/inventories/v1/regionalinventory.rb', line 94

class RegionalInventory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end