Class: Google::Shopping::Merchant::Inventories::V1::LocalInventory
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Inventories::V1::LocalInventory
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/inventories/v1/localinventory.rb
Overview
Local inventory information for the product. Represents in-store information
for a specific product at the store specified by
storeCode.
For a list of all accepted attribute values, see the local product inventory
data specification.
Instance Attribute Summary collapse
-
#account ⇒ ::Integer
readonly
Output only.
-
#base64_encoded_name ⇒ ::String
readonly
Output only.
-
#local_inventory_attributes ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes
Optional.
-
#name ⇒ ::String
readonly
Output only.
-
#store_code ⇒ ::String
Required.
Instance Attribute Details
#account ⇒ ::Integer (readonly)
Returns Output only. The account that owns the product. This field will be ignored if set by the client.
92 93 94 95 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/localinventory.rb', line 92 class LocalInventory include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#base64_encoded_name ⇒ ::String (readonly)
Returns Output only. The unpadded base64url encoded name of the LocalInventory
resource. Format:
accounts/{account}/products/{product}/localInventories/{store_code}
where the {product} segment is the unpadded base64url encoded value of
the identifier of the form content_language~feed_label~offer_id. Example:
accounts/123/products/ZW5-VVN-c2t1LzEyMw/localInventories/store123 for
the decoded product ID en~US~sku/123 and store_code "store123".
Can be used directly as input to the API methods that require the local
product identifier within the local inventory name to be encoded if it
contains special characters, for example
GetLocalInventory.
92 93 94 95 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/localinventory.rb', line 92 class LocalInventory include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#local_inventory_attributes ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes
Returns Optional. A list of local inventory attributes.
92 93 94 95 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/localinventory.rb', line 92 class LocalInventory include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. The name of the LocalInventory resource.
Format:
accounts/{account}/products/{product}/localInventories/{store_code}
The {product} segment is a unique identifier for the product.
This identifier must be unique within a merchant account and generally
follows the structure: content_language~feed_label~offer_id. Example:
en~US~sku123 For legacy local products, the structure is:
local~content_language~feed_label~offer_id. Example: local~en~US~sku123
The format of the {product} segment in the URL is automatically detected
by the server, supporting two options:
Encoded Format: The
{product}segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in thecontent_language~feed_label~offer_idstructure. This encoding MUST be used if any part of the product identifier (likeoffer_id) contains characters such as/,%, or~.- Example: To represent the product ID
en~US~sku/123forstore_code"store123", the{product}segment must be the base64url encoding of this string, which isZW5-VVN-c2t1LzEyMw. The full resource name for the local inventory would beaccounts/123/products/ZW5-VVN-c2t1LzEyMw/localInventories/store123.
- Example: To represent the product ID
Plain Format: The
{product}segment is the tilde-separated stringcontent_language~feed_label~offer_id. This format is suitable only whencontent_language,feed_label, andoffer_iddo not contain URL-problematic characters like/,%, or~.
We recommend using the Encoded Format for all product IDs to ensure
correct parsing, especially those containing special characters. The
presence of tilde (~) characters in the {product} segment is used to
differentiate between the two formats.
92 93 94 95 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/localinventory.rb', line 92 class LocalInventory include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#store_code ⇒ ::String
Returns Required. Immutable. Store code (the store ID from your Business Profile) of the physical store the product is sold in. See the Local product inventory data specification for more information.
92 93 94 95 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/localinventory.rb', line 92 class LocalInventory include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |