Class: Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb
Overview
Local inventory attributes.
Defined Under Namespace
Modules: Availability, PickupMethod, PickupSla
Instance Attribute Summary collapse
-
#availability ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::Availability
Availability of the product at this store.
-
#instore_product_location ⇒ ::String
Optional.
-
#loyalty_programs ⇒ ::Array<::Google::Shopping::Merchant::Inventories::V1::InventoryLoyaltyProgram>
Optional.
-
#pickup_method ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::PickupMethod
Optional.
-
#pickup_sla ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::PickupSla
Optional.
-
#price ⇒ ::Google::Shopping::Type::Price
Optional.
-
#quantity ⇒ ::Integer
Optional.
-
#sale_price ⇒ ::Google::Shopping::Type::Price
Optional.
-
#sale_price_effective_date ⇒ ::Google::Type::Interval
Optional.
Instance Attribute Details
#availability ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::Availability
Returns Availability of the product at this store.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |
#instore_product_location ⇒ ::String
Returns Optional. Location of the product inside the store. Maximum length is 20 bytes.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |
#loyalty_programs ⇒ ::Array<::Google::Shopping::Merchant::Inventories::V1::InventoryLoyaltyProgram>
Returns Optional. An optional list of loyalty programs containing applicable loyalty member prices for this product at this store.
This field is used to show store-specific member prices on Local Inventory Ads (LIA).
To use this, the loyalty program must be configured in Google Merchant Center. The benefits provided must match the merchant's website and be clear to members. This is only applicable for merchants in supported countries.
See Loyalty program for details on supported countries and loyalty program configuration. For local inventory specific details, see the Local inventory data specification.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |
#pickup_method ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::PickupMethod
Returns Optional. Supported pickup
method for this
product. Unless the value is "not supported", this field must be
submitted together with pickupSla.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |
#pickup_sla ⇒ ::Google::Shopping::Merchant::Inventories::V1::LocalInventoryAttributes::PickupSla
Returns Optional. Relative time period from the order date for an order for this
product, from this store, to be ready for pickup. Must be submitted with
pickupMethod. See more details
here.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |
#price ⇒ ::Google::Shopping::Type::Price
Returns Optional. Price of the product at this store.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |
#quantity ⇒ ::Integer
Returns Optional. Quantity of the product available at this store. Must be greater than or equal to zero.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |
#sale_price ⇒ ::Google::Shopping::Type::Price
Returns Optional. Sale price of the product at this store. Mandatory if
[salePriceEffectiveDate][LocalInventory.sale_price_effective_date] is
defined.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |
#sale_price_effective_date ⇒ ::Google::Type::Interval
Returns Optional. The TimePeriod of the
sale at this store.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 79 class LocalInventoryAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Availability](https://support.google.com/merchants/answer/3061342) of the # product at this store. module Availability # Indicates that the availability is unspecified. LOCAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0 # Indicates that the product is in stock. IN_STOCK = 1 # Indicates that the product is out of stock. LIMITED_AVAILABILITY = 2 # Indicates that the product is on display to order. ON_DISPLAY_TO_ORDER = 3 # Indicates that the product is out of stock. OUT_OF_STOCK = 4 end # Supported [pickup # method](https://support.google.com/merchants/answer/3061342) for this # product. Unless the value is `"not supported"`, this field must be # submitted together with `pickupSla`. module PickupMethod # Indicates that the pickup method is unspecified. PICKUP_METHOD_UNSPECIFIED = 0 # Indicates that the pickup method is Buy. BUY = 1 # Indicates that the pickup method is Reserve. RESERVE = 2 # Indicates that the pickup method is Ship to store. SHIP_TO_STORE = 3 # Indicates that the pickup method is not supported. NOT_SUPPORTED = 4 end # Relative time period from the order date for an order for this product, # from this store, to be ready for pickup. Must be submitted with # `pickupMethod`. See more details # [here](https://support.google.com/merchants/answer/3061342). module PickupSla # Indicates that the pickup SLA is unspecified. PICKUP_SLA_UNSPECIFIED = 0 # Indicates that the pickup SLA is same day. SAME_DAY = 1 # Indicates that the pickup SLA is next day. NEXT_DAY = 2 # Indicates that the pickup SLA is two days. TWO_DAY = 3 # Indicates that the pickup SLA is three days. THREE_DAY = 4 # Indicates that the pickup SLA is four days. FOUR_DAY = 5 # Indicates that the pickup SLA is five days. FIVE_DAY = 6 # Indicates that the pickup SLA is six days. SIX_DAY = 7 # Indicates that the pickup SLA is seven days. SEVEN_DAY = 8 # Indicates that the pickup SLA is multi-week. MULTI_WEEK = 9 end end |