Class: Google::Shopping::Merchant::Inventories::V1::RegionalInventoryAttributes

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb

Overview

Regional inventory attributes.

Defined Under Namespace

Modules: Availability

Instance Attribute Summary collapse

Instance Attribute Details

#availability::Google::Shopping::Merchant::Inventories::V1::RegionalInventoryAttributes::Availability

Returns Optional. Availability of the product in this region.



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 238

class RegionalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/14644124) of the
  # product in this region.
  module Availability
    # Indicates that the availability is unspecified.
    REGIONAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 2
  end
end

#loyalty_programs::Array<::Google::Shopping::Merchant::Inventories::V1::InventoryLoyaltyProgram>

Returns Optional. An optional list of loyalty programs containing applicable loyalty member prices for this product in this region.

This field is used to show region-specific member prices on Product Listing Ads (PLA).

To use this, the loyalty program must be configured in Google Merchant Center, and the merchant must be using the Regional Availability and Pricing (RAAP) feature. The benefits provided must match the merchant's website and be clear to members. This is only applicable for merchants in supported countries.

See Loyalty program for details on supported countries and loyalty program configuration. Also see Regional availability and pricing and How to set up regional member pricing for more information.

Returns:

  • (::Array<::Google::Shopping::Merchant::Inventories::V1::InventoryLoyaltyProgram>)

    Optional. An optional list of loyalty programs containing applicable loyalty member prices for this product in this region.

    This field is used to show region-specific member prices on Product Listing Ads (PLA).

    To use this, the loyalty program must be configured in Google Merchant Center, and the merchant must be using the Regional Availability and Pricing (RAAP) feature. The benefits provided must match the merchant's website and be clear to members. This is only applicable for merchants in supported countries.

    See Loyalty program for details on supported countries and loyalty program configuration. Also see Regional availability and pricing and How to set up regional member pricing for more information.



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 238

class RegionalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/14644124) of the
  # product in this region.
  module Availability
    # Indicates that the availability is unspecified.
    REGIONAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 2
  end
end

#price::Google::Shopping::Type::Price

Returns Optional. Price of the product in this region.

Returns:



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 238

class RegionalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/14644124) of the
  # product in this region.
  module Availability
    # Indicates that the availability is unspecified.
    REGIONAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 2
  end
end

#sale_price::Google::Shopping::Type::Price

Returns Optional. Sale price of the product in this region. Mandatory if [salePriceEffectiveDate][RegionalInventory.sale_price_effective_date] is defined.

Returns:

  • (::Google::Shopping::Type::Price)

    Optional. Sale price of the product in this region. Mandatory if [salePriceEffectiveDate][RegionalInventory.sale_price_effective_date] is defined.



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 238

class RegionalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/14644124) of the
  # product in this region.
  module Availability
    # Indicates that the availability is unspecified.
    REGIONAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 2
  end
end

#sale_price_effective_date::Google::Type::Interval

Returns Optional. The TimePeriod of the sale price in this region.

Returns:



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'proto_docs/google/shopping/merchant/inventories/v1/inventories_common.rb', line 238

class RegionalInventoryAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Availability](https://support.google.com/merchants/answer/14644124) of the
  # product in this region.
  module Availability
    # Indicates that the availability is unspecified.
    REGIONAL_INVENTORY_AVAILABILITY_UNSPECIFIED = 0

    # Indicates that the product is in stock.
    IN_STOCK = 1

    # Indicates that the product is out of stock.
    OUT_OF_STOCK = 2
  end
end